import time
import board
import busio
import adafruit_ads1x15.ads1115 as ADS
from adafruit_ads1x15.analog_in import AnalogIn
import math

# Erstelle den I2C-Bus
i2c = busio.I2C(board.SCL, board.SDA)

# Erstelle das ADC-Objekt mit dem I2C-Bus
ads = ADS.ADS1115(i2c)

# Maximal mögliche Spannung definieren (abhängig von Ihrer Referenzspannung)
voltageMax = 3.3

# Einzelne Eingänge an Kanälen erstellen
chan0 = AnalogIn(ads, ADS.P0)
chan1 = AnalogIn(ads, ADS.P1)
chan2 = AnalogIn(ads, ADS.P2)
chan3 = AnalogIn(ads, ADS.P3)

# Hauptprogrammschleife
while True:
    # Berechnung der Temperatur über einen NTC-Widerstand
    ntc_resistance = ((chan0.voltage / voltageMax) * 10000) / (1 - (chan0.voltage / voltageMax))
    temperatur = 1 / ((1 / 298.15) + (1 / 3950) * math.log(ntc_resistance / 10000))
    temperatur -= 273.15  # Umwandlung von Kelvin in Celsius
    print("Temperatur: {:.2f} °C".format(temperatur))
    print("---------------------------------------------------")
    time.sleep(1)